Package: marcher
Type: Package
Title: Migration and Range Change Estimation in R
Version: 0.0-2
Authors@R: c(person("Eliezer", "Gurarie", role = c("aut", "cre"), email = "egurarie@umd.edu"), person("Farid", "Cheraghi", role = "aut"))
Description: A set of tools for likelihood-based estimation, model selection and testing of two- and three-range shift and migration models for animal movement data as described in Gurarie et al. (2017) <doi: 10.1111/1365-2656.12674>.  Provided movement data (X, Y and Time), including irregularly sampled data, functions estimate the time, duration and location of one or two range shifts, as well as the ranging area and auto-correlation structure of the movment.  Tests assess, for example, whether the shift was "significant", and whether a two-shift migration was a true return migration.
License: GPL-2
Depends: R (>= 3.3.0)
Imports: stats, Matrix, graphics, grDevices, plyr, mvtnorm,
        RColorBrewer, minpack.lm, zoo, numDeriv, magrittr, scales
VignetteBuilder: knitr
BugReports: https://github.com/EliGurarie/marcher/issues
RoxygenNote: 6.0.1
Suggests: knitr, rmarkdown, lubridate
NeedsCompilation: no
Packaged: 2017-04-12 02:31:07 UTC; Farid
Author: Eliezer Gurarie [aut, cre],
  Farid Cheraghi [aut]
Maintainer: Eliezer Gurarie <egurarie@umd.edu>
Repository: CRAN
Date/Publication: 2017-04-12 14:26:18 UTC
Built: R 4.6.0; ; 2026-04-26 01:09:15 UTC; unix
