# Generated by roxygen2: do not edit by hand

S3method(AIC,shiftfit)
S3method(logLik,shiftfit)
S3method(plot,shiftfit)
S3method(print,shiftfit)
S3method(summary,shiftfit)
export(estimate_shift)
export(fitNSD)
export(getArea)
export(getCov)
export(getLikelihood)
export(getMu)
export(getMu_multi)
export(getRSI)
export(getTau)
export(locate_shift)
export(mvrnorm2)
export(quickfit)
export(scan_track)
export(selectModel)
export(simulate_shift)
export(test_rangeshift)
export(test_return)
export(test_stopover)
import(RColorBrewer)
import(graphics)
import(magrittr)
import(minpack.lm)
import(mvtnorm)
import(numDeriv)
import(plyr)
importFrom(Matrix,solve)
importFrom(grDevices,grey)
importFrom(grDevices,rgb)
importFrom(scales,alpha)
importFrom(stats,AIC)
importFrom(stats,arima)
importFrom(stats,dnorm)
importFrom(stats,kmeans)
importFrom(stats,lm)
importFrom(stats,optim)
importFrom(stats,pchisq)
importFrom(stats,qqnorm)
importFrom(stats,quantile)
importFrom(stats,rnorm)
importFrom(stats,sd)
importFrom(stats,smooth)
importFrom(stats,var)
importFrom(zoo,zoo)
